// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.mnfc;

import netscape.application.*;

import com.micronova.mnfc.IToolTipManager;

/**

   IApplication supports tooltip for any View.<BR>
   To enable tooltips, simply subclass IApplication instead of Application.

   * @author Makoto Nagata, MicroNova
   * @version 1.0

*/

public class IApplication extends Application
{
    IToolTipManager toolTipManager;
    View lastMouseView;

    /** 

        Constructs an IApplication with default IToolTipManager.

    */

    public IApplication()
    {
        super();

        toolTipManager = new IToolTipManager();
    }

    /**

       Returns the IToolTipManager for this IApplication.

    */

    public IToolTipManager getToolTipManager()
    {
        return toolTipManager;
    }
    
    /**

       Sets the IToolTipManager.

    */

    public void setToolTipManager(IToolTipManager toolTipManager)
    {
        this.toolTipManager = toolTipManager;
    }

    /**

       Overridden to handle tooltips.
       
    */

    public void didProcessEvent(Event event)
    {
        super.didProcessEvent(event);

        if (toolTipManager.isEnabled())
        {
            if (event instanceof MouseEvent)
            {
                MouseEvent mouseEvent = (MouseEvent)event;

                int type = mouseEvent.type();

                View view = mouseEvent.rootView().viewForMouse(mouseEvent.x, mouseEvent.y);
                switch (type)
                {
                    case MouseEvent.MOUSE_MOVED:
                    {
                        if (lastMouseView != view)
                        {
                            toolTipManager.mouseExited(lastMouseView, mouseEvent);
                            toolTipManager.mouseEntered(view, mouseEvent);
                        }
                        
                        toolTipManager.mouseMoved(view, mouseEvent);
                    }
                    break;

                    case MouseEvent.MOUSE_ENTERED:
                    {
                        toolTipManager.mouseEntered(view, mouseEvent);
                    }
                    break;
                
                    default:
                    {
                        toolTipManager.mouseExited(lastMouseView, null);
                        view = null;
                    }
                    break;
                }

                lastMouseView = view;
            }
        }
        else
        {
             toolTipManager.mouseExited(null, null);
        }
    }
}





