// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.mnfc;

import netscape.application.*;

/**

   IToolTip provides static methods for easy tooltip handling.
   This class is used by IToolTipManager to hold tooltip data.

   * @author Makoto Nagata, MicroNova
   * @version 1.0
   
*/

public class IToolTip
{
    /**

       Retrieves the IToolTipManager attached to the current Application.
       Returns null if the current Application is not an instance of
       com.micronova.mnfc.IApplication.

    */

    public static IToolTipManager getToolTipManager()
    {
        Application application = Application.application();

        if (application instanceof IApplication)
        {
            return ((IApplication)application).getToolTipManager();
        }
        else
        {
            return null;
        }
    }

    /**
       
       Registers a tooltip for a view (with the IToolTipManager for
       the current application, if one is available).

    */

    public static void registerToolTip(View view, String toolTip)
    {
        IToolTipManager toolTipManager = getToolTipManager();

        if (toolTipManager != null)
        {
            toolTipManager.registerToolTip(view, toolTip);
        }
    }

    /**

       Unregisters a tooltip for a view (with the IToolTipManager
       for the current application, if one is available).

    */

    public static void unregisterToolTip(View view)
    {
        IToolTipManager toolTipManager = getToolTipManager();

        if (toolTipManager != null)
        {
            toolTipManager.unregisterToolTip(view);
        }
    }

    /**

       Unregisters tooltips for the given view and all its descendents
       (with the IToolTipManager for the current application, if one
       is available).

    */

    public static void unregisterToolTipForDescendents(View view)
    {
        IToolTipManager toolTipManager = getToolTipManager();

        if (toolTipManager != null)
        {
            toolTipManager.unregisterToolTipForDescendents(view);
        }
    }

    View view;
    String tipText;

    /** 

        Constructs an empty IToolTip.

    */

    public IToolTip()
    {
        this(null, null);
    }

    /**

       Constructs an IToolTip for a given View and a tipText string.

    */

    public IToolTip(View view, String tipText)
    {
        this.view = view;
        this.tipText = tipText;
    }

    /**

       Sets the View for this tooltip.

    */

    public void setView(View view)
    {
        this.view = view;
    }

    /**

       Returns the View for this tooltip.

    */

    public View getView()
    {
        return view;
    }

    /**

       Sets the text for this tooltip.

    */

    public void setTipText(String tipText)
    {
        this.tipText = tipText;
    }

    /**

       Returns the text for this tooltip.

    */

    public String getTipText()
    {
        return tipText;
    }
}





